pyntcore documentation
======================

This is a wrapper around the WPILib NTCore C++ implementation. In FRC, the
NetworkTables protocol is used to pass non-Driver Station data to and from
the robot across the network.

.. note:: NetworkTables is a protocol used for robot communication in the
          FIRST Robotics Competition. It does not have any security, and
          should never be used on untrusted networks.

.. include:: _sidebar.rst.inc
    
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`